==> apache-iotdb-1.3.5-source-release.zip: apache-iotdb-1.3.5/integration-test/src/test/java/org/apache/iotdb/confignode/it/removedatanode/IoTDBRemoveDataNodeNormalIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.confignode.it.removedatanode;

import org.apache.iotdb.it.framework.IoTDBTestRunner;
import org.apache.iotdb.itbase.category.ClusterIT;

import org.junit.Test;
import org.junit.experimental.categories.Category;
import org.junit.runner.RunWith;

@Category({ClusterIT.class})
@RunWith(IoTDBTestRunner.class)
public class IoTDBRemoveDataNodeNormalIT extends IoTDBRemoveDataNodeITFramework {

  @Test
  public void success1C4DTest() throws Exception {
    successTest(2, 3, 1, 4, 1, 2, true, SQLModel.NOT_USE_SQL);
  }

  @Test
  public void fail1C3DTest() throws Exception {
    failTest(2, 3, 1, 3, 1, 2, false, SQLModel.NOT_USE_SQL);
  }

  @Test
  public void success1C4DTestUseSQL() throws Exception {
    successTest(2, 3, 1, 4, 1, 2, true, SQLModel.TREE_MODEL_SQL);
  }

  @Test
  public void fail1C3DTestUseSQL() throws Exception {
    failTest(2, 3, 1, 3, 1, 2, false, SQLModel.TREE_MODEL_SQL);
  }
}

==> apache-iotdb-2.0.3-source-release.zip: apache-iotdb-2.0.3/integration-test/src/test/java/org/apache/iotdb/confignode/it/removedatanode/IoTDBRemoveDataNodeNormalIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.confignode.it.removedatanode;

import org.apache.iotdb.it.framework.IoTDBTestRunner;
import org.apache.iotdb.itbase.category.ClusterIT;

import org.junit.Test;
import org.junit.experimental.categories.Category;
import org.junit.runner.RunWith;

@Category({ClusterIT.class})
@RunWith(IoTDBTestRunner.class)
public class IoTDBRemoveDataNodeNormalIT extends IoTDBRemoveDataNodeITFramework {

  @Test
  public void success1C4DTest() throws Exception {
    successTest(2, 3, 1, 4, 1, 2, true, SQLModel.NOT_USE_SQL);
  }

  @Test
  public void fail1C3DTest() throws Exception {
    failTest(2, 3, 1, 3, 1, 2, false, SQLModel.NOT_USE_SQL);
  }

  @Test
  public void success1C4DTestUseSQL() throws Exception {
    successTest(2, 3, 1, 4, 1, 2, true, SQLModel.TREE_MODEL_SQL);
  }

  @Test
  public void fail1C3DTestUseSQL() throws Exception {
    failTest(2, 3, 1, 3, 1, 2, false, SQLModel.TREE_MODEL_SQL);
  }

  @Test
  public void success1C4DTestUseTableSQL() throws Exception {
    successTest(2, 3, 1, 4, 1, 2, true, SQLModel.TABLE_MODEL_SQL);
  }

  @Test
  public void fail1C3DTestUseTableSQL() throws Exception {
    failTest(2, 3, 1, 3, 1, 2, false, SQLModel.TABLE_MODEL_SQL);
  }
}
